@@ -233,14 +233,15 @@ func (s *ProxyServer) Start(config *goconf.ConfigFile) error {
 		mcuType = signaling.McuTypeDefault
 	}
 
-	interrupt := make(chan os.Signal, 1)
-	signal.Notify(interrupt, os.Interrupt)
-	defer signal.Stop(interrupt)
+	backoff, err := signaling.NewExponentialBackoff(initialMcuRetry, maxMcuRetry)
+	if err != nil {
+		return err
+	}
+
+	ctx, stop := signal.NotifyContext(context.Background(), os.Interrupt)
+	defer stop()
 
-	var err error
 	var mcu signaling.Mcu
-	mcuRetry := initialMcuRetry
-	mcuRetryTimer := time.NewTimer(mcuRetry)
 	for {
 		switch mcuType {
 		case signaling.McuTypeJanus:
@@ -263,17 +264,10 @@ func (s *ProxyServer) Start(config *goconf.ConfigFile) error {
 			break
 		}
 
-		log.Printf("Could not initialize %s MCU at %s (%s) will retry in %s", mcuType, s.url, err, mcuRetry)
-		mcuRetryTimer.Reset(mcuRetry)
-		select {
-		case <-interrupt:
+		log.Printf("Could not initialize %s MCU at %s (%s) will retry in %s", mcuType, s.url, err, backoff.NextWait())
+		backoff.Wait(ctx)
+		if ctx.Err() != nil {
 			return fmt.Errorf("Cancelled")
-		case <-mcuRetryTimer.C:
-			// Retry connection
-			mcuRetry = mcuRetry * 2
-			if mcuRetry > maxMcuRetry {
-				mcuRetry = maxMcuRetry
-			}
 		}
 	}
 
@@ -305,9 +299,7 @@ loop:
 }
 
 func (s *ProxyServer) updateLoad() {
-	// TODO: Take maximum bandwidth of clients into account when calculating
-	// load (screensharing requires more than regular audio/video).
-	load := s.GetClientCount()
+	load := s.GetClientsLoad()
 	if load == s.load.Load() {
 		return
 	}
@@ -390,7 +382,7 @@ func (s *ProxyServer) ScheduleShutdown() {
 		session.sendMessage(msg)
 	})
 
-	if s.GetClientCount() == 0 {
+	if !s.HasClients() {
 		go close(s.shutdownChannel)
 	}
 }
@@ -653,12 +645,13 @@ func (s *ProxyServer) processCommand(ctx context.Context, client *ProxyClient, s
 			Id:   message.Id,
 			Type: "command",
 			Command: &signaling.CommandProxyServerMessage{
-				Id: id,
+				Id:      id,
+				Bitrate: int(publisher.MaxBitrate()),
 			},
 		}
 		session.sendMessage(response)
-		statsPublishersCurrent.WithLabelValues(cmd.StreamType).Inc()
-		statsPublishersTotal.WithLabelValues(cmd.StreamType).Inc()
+		statsPublishersCurrent.WithLabelValues(string(cmd.StreamType)).Inc()
+		statsPublishersTotal.WithLabelValues(string(cmd.StreamType)).Inc()
 	case "create-subscriber":
 		id := uuid.New().String()
 		publisherId := cmd.PublisherId
@@ -686,8 +679,8 @@ func (s *ProxyServer) processCommand(ctx context.Context, client *ProxyClient, s
 			},
 		}
 		session.sendMessage(response)
-		statsSubscribersCurrent.WithLabelValues(cmd.StreamType).Inc()
-		statsSubscribersTotal.WithLabelValues(cmd.StreamType).Inc()
+		statsSubscribersCurrent.WithLabelValues(string(cmd.StreamType)).Inc()
+		statsSubscribersTotal.WithLabelValues(string(cmd.StreamType)).Inc()
 	case "delete-publisher":
 		client := s.GetClient(cmd.ClientId)
 		if client == nil {
@@ -707,7 +700,7 @@ func (s *ProxyServer) processCommand(ctx context.Context, client *ProxyClient, s
 		}
 
 		if s.DeleteClient(cmd.ClientId, client) {
-			statsPublishersCurrent.WithLabelValues(client.StreamType()).Dec()
+			statsPublishersCurrent.WithLabelValues(string(client.StreamType())).Dec()
 		}
 
 		go func() {
@@ -742,7 +735,7 @@ func (s *ProxyServer) processCommand(ctx context.Context, client *ProxyClient, s
 		}
 
 		if s.DeleteClient(cmd.ClientId, client) {
-			statsSubscribersCurrent.WithLabelValues(client.StreamType()).Dec()
+			statsSubscribersCurrent.WithLabelValues(string(client.StreamType())).Dec()
 		}
 
 		go func() {
@@ -978,10 +971,21 @@ func (s *ProxyServer) DeleteClient(id string, client signaling.McuClient) bool {
 	return true
 }
 
-func (s *ProxyServer) GetClientCount() int64 {
+func (s *ProxyServer) HasClients() bool {
 	s.clientsLock.RLock()
 	defer s.clientsLock.RUnlock()
-	return int64(len(s.clients))
+	return len(s.clients) > 0
+}
+
+func (s *ProxyServer) GetClientsLoad() int64 {
+	s.clientsLock.RLock()
+	defer s.clientsLock.RUnlock()
+
+	var load int64
+	for _, c := range s.clients {
+		load += int64(c.MaxBitrate())
+	}
+	return load / 1024
 }
 
 func (s *ProxyServer) GetClient(id string) signaling.McuClient {
