@@ -34,6 +34,7 @@ import (
 	"reflect"
 	"strconv"
 	"strings"
+	"sync"
 	"testing"
 	"time"
 
@@ -211,6 +212,7 @@ type TestClient struct {
 	hub    *Hub
 	server *httptest.Server
 
+	mu        sync.Mutex
 	conn      *websocket.Conn
 	localAddr net.Addr
 
@@ -280,6 +282,8 @@ func (c *TestClient) CloseWithBye() {
 }
 
 func (c *TestClient) Close() {
+	c.mu.Lock()
+	defer c.mu.Unlock()
 	if err := c.conn.WriteMessage(websocket.CloseMessage, []byte{}); err == websocket.ErrCloseSent {
 		// Already closed
 		return
@@ -368,6 +372,8 @@ func (c *TestClient) WriteJSON(data interface{}) error {
 		}
 	}
 
+	c.mu.Lock()
+	defer c.mu.Unlock()
 	return c.conn.WriteJSON(data)
 }
 
@@ -578,7 +584,19 @@ func (c *TestClient) SendInternalRemoveSession(msg *RemoveSessionInternalClientM
 	return c.WriteJSON(message)
 }
 
-func (c *TestClient) SetTransientData(key string, value interface{}) error {
+func (c *TestClient) SendInternalDialout(msg *DialoutInternalClientMessage) error {
+	message := &ClientMessage{
+		Id:   "abcd",
+		Type: "internal",
+		Internal: &InternalClientMessage{
+			Type:    "dialout",
+			Dialout: msg,
+		},
+	}
+	return c.WriteJSON(message)
+}
+
+func (c *TestClient) SetTransientData(key string, value interface{}, ttl time.Duration) error {
 	payload, err := json.Marshal(value)
 	if err != nil {
 		c.t.Fatal(err)
@@ -591,6 +609,7 @@ func (c *TestClient) SetTransientData(key string, value interface{}) error {
 			Type:  "set",
 			Key:   key,
 			Value: (*json.RawMessage)(&payload),
+			TTL:   ttl,
 		},
 	}
 	return c.WriteJSON(message)
