@@ -711,40 +711,3 @@ func TestVirtualSessionCleanup(t *testing.T) {
 		t.Error(err)
 	}
 }
-
-func TestVirtualSessionFlags(t *testing.T) {
-	s := &VirtualSession{
-		publicId: "dummy-for-testing",
-	}
-	if s.Flags() != 0 {
-		t.Fatalf("Expected flags 0, got %d", s.Flags())
-	}
-	s.AddFlags(1)
-	if s.Flags() != 1 {
-		t.Fatalf("Expected flags 1, got %d", s.Flags())
-	}
-	s.AddFlags(1)
-	if s.Flags() != 1 {
-		t.Fatalf("Expected flags 1, got %d", s.Flags())
-	}
-	s.AddFlags(2)
-	if s.Flags() != 3 {
-		t.Fatalf("Expected flags 3, got %d", s.Flags())
-	}
-	s.RemoveFlags(1)
-	if s.Flags() != 2 {
-		t.Fatalf("Expected flags 2, got %d", s.Flags())
-	}
-	s.RemoveFlags(1)
-	if s.Flags() != 2 {
-		t.Fatalf("Expected flags 2, got %d", s.Flags())
-	}
-	s.AddFlags(3)
-	if s.Flags() != 3 {
-		t.Fatalf("Expected flags 3, got %d", s.Flags())
-	}
-	s.RemoveFlags(1)
-	if s.Flags() != 2 {
-		t.Fatalf("Expected flags 2, got %d", s.Flags())
-	}
-}
